@@ -2,7 +2,7 @@ use lychee_lib::{CacheStatus, ResponseBody, Status};
 
 use crate::formatters::color::{DIM, GREEN, NORMAL, PINK, YELLOW};
 
-use super::{ResponseFormatter, MAX_RESPONSE_OUTPUT_WIDTH};
+use super::{MAX_RESPONSE_OUTPUT_WIDTH, ResponseFormatter};
 
 /// A colorized formatter for the response body
 ///
@@ -13,7 +13,7 @@ pub(crate) struct ColorFormatter;
 impl ColorFormatter {
     /// Determine the color for formatted output based on the status of the
     /// response.
-    fn status_color(status: &Status) -> &'static once_cell::sync::Lazy<console::Style> {
+    fn status_color(status: &Status) -> &'static std::sync::LazyLock<console::Style> {
         match status {
             Status::Ok(_) | Status::Cached(CacheStatus::Ok(_)) => &GREEN,
             Status::Excluded
