@@ -9,8 +9,8 @@ use http::StatusCode;
 use lychee_lib::{InputSource, ResponseBody, Status};
 use std::fmt::Write;
 use tabled::{
-    settings::{object::Segment, Alignment, Modify, Style},
     Table, Tabled,
+    settings::{Alignment, Modify, Style, object::Segment},
 };
 
 use crate::stats::ResponseStats;
@@ -53,6 +53,10 @@ fn stats_table(stats: &ResponseStats) -> String {
             status: "\u{1f6ab} Errors",
             count: stats.errors,
         },
+        StatsTableEntry {
+            status: "\u{26d4} Unsupported",
+            count: stats.unsupported,
+        },
     ];
     let style = Style::markdown();
 
@@ -67,10 +71,9 @@ fn stats_table(stats: &ResponseStats) -> String {
 /// Optional details get added if available.
 fn markdown_response(response: &ResponseBody) -> Result<String> {
     let mut formatted = format!(
-        "* [{}] [{}]({})",
+        "* [{}] <{}>",
         response.status.code_as_string(),
         response.uri,
-        response.uri,
     );
 
     if let Status::Ok(StatusCode::OK) = response.status {
@@ -127,7 +130,7 @@ where
 {
     if !&map.is_empty() {
         writeln!(f, "\n## {name} per input")?;
-        for (source, responses) in map {
+        for (source, responses) in super::sort_stat_map(map) {
             writeln!(f, "\n### {name} in {source}\n")?;
             for response in responses {
                 writeln!(f, "{}", write_stat(response)?)?;
@@ -155,12 +158,11 @@ impl StatsFormatter for Markdown {
 
 #[cfg(test)]
 mod tests {
-
     use http::StatusCode;
     use lychee_lib::{CacheStatus, InputSource, Response, ResponseBody, Status, Uri};
     use reqwest::Url;
 
-    use crate::archive::Suggestion;
+    use crate::formatters::suggestion::Suggestion;
 
     use super::*;
 
@@ -171,10 +173,7 @@ mod tests {
             status: Status::Ok(StatusCode::OK),
         };
         let markdown = markdown_response(&response).unwrap();
-        assert_eq!(
-            markdown,
-            "* [200] [http://example.com/](http://example.com/)"
-        );
+        assert_eq!(markdown, "* [200] <http://example.com/>");
     }
 
     #[test]
@@ -184,10 +183,7 @@ mod tests {
             status: Status::Cached(CacheStatus::Ok(200)),
         };
         let markdown = markdown_response(&response).unwrap();
-        assert_eq!(
-            markdown,
-            "* [200] [http://example.com/](http://example.com/) | OK (cached)"
-        );
+        assert_eq!(markdown, "* [200] <http://example.com/> | OK (cached)");
     }
 
     #[test]
@@ -197,25 +193,23 @@ mod tests {
             status: Status::Cached(CacheStatus::Error(Some(400))),
         };
         let markdown = markdown_response(&response).unwrap();
-        assert_eq!(
-            markdown,
-            "* [400] [http://example.com/](http://example.com/) | Error (cached)"
-        );
+        assert_eq!(markdown, "* [400] <http://example.com/> | Error (cached)");
     }
 
     #[test]
     fn test_render_stats() {
         let stats = ResponseStats::default();
         let table = stats_table(&stats);
-        let expected = "| Status        | Count |
-|---------------|-------|
-| 🔍 Total      | 0     |
-| ✅ Successful | 0     |
-| ⏳ Timeouts   | 0     |
-| 🔀 Redirected | 0     |
-| 👻 Excluded   | 0     |
-| ❓ Unknown    | 0     |
-| 🚫 Errors     | 0     |";
+        let expected = "| Status         | Count |
+|----------------|-------|
+| 🔍 Total       | 0     |
+| ✅ Successful  | 0     |
+| ⏳ Timeouts    | 0     |
+| 🔀 Redirected  | 0     |
+| 👻 Excluded    | 0     |
+| ❓ Unknown     | 0     |
+| 🚫 Errors      | 0     |
+| ⛔ Unsupported | 0     |";
         assert_eq!(table, expected.to_string());
     }
 
@@ -239,21 +233,22 @@ mod tests {
         let summary = MarkdownResponseStats(stats);
         let expected = "# Summary
 
-| Status        | Count |
-|---------------|-------|
-| 🔍 Total      | 1     |
-| ✅ Successful | 0     |
-| ⏳ Timeouts   | 0     |
-| 🔀 Redirected | 0     |
-| 👻 Excluded   | 0     |
-| ❓ Unknown    | 0     |
-| 🚫 Errors     | 1     |
+| Status         | Count |
+|----------------|-------|
+| 🔍 Total       | 1     |
+| ✅ Successful  | 0     |
+| ⏳ Timeouts    | 0     |
+| 🔀 Redirected  | 0     |
+| 👻 Excluded    | 0     |
+| ❓ Unknown     | 0     |
+| 🚫 Errors      | 1     |
+| ⛔ Unsupported | 0     |
 
 ## Errors per input
 
 ### Errors in stdin
 
-* [404] [http://127.0.0.1/](http://127.0.0.1/) | Error (cached)
+* [404] <http://127.0.0.1/> | Error (cached)
 
 ## Suggestions per input
 
