@@ -63,23 +63,24 @@ use std::io::{self, BufRead, BufReader, ErrorKind, Write};
 use std::path::PathBuf;
 use std::sync::Arc;
 
-use anyhow::{bail, Context, Error, Result};
+use anyhow::{Context, Error, Result, bail};
 use clap::Parser;
 use commands::CommandParams;
 use formatters::{get_stats_formatter, log::init_logging};
+use http::HeaderMap;
 use log::{error, info, warn};
 
+use lychee_lib::filter::PathExcludes;
 #[cfg(feature = "native-tls")]
 use openssl_sys as _; // required for vendored-openssl feature
 
-use options::LYCHEE_CONFIG_FILE;
+use options::{HeaderMapExt, LYCHEE_CONFIG_FILE};
 use ring as _; // required for apple silicon
 
 use lychee_lib::BasicAuthExtractor;
 use lychee_lib::Collector;
 use lychee_lib::CookieJar;
 
-mod archive;
 mod cache;
 mod client;
 mod commands;
@@ -95,7 +96,7 @@ use crate::formatters::duration::Duration;
 use crate::{
     cache::{Cache, StoreExt},
     formatters::stats::StatsFormatter,
-    options::{Config, LycheeOptions, LYCHEE_CACHE_FILE, LYCHEE_IGNORE_FILE},
+    options::{Config, LYCHEE_CACHE_FILE, LYCHEE_IGNORE_FILE, LycheeOptions},
 };
 
 /// A C-like enum that can be cast to `i32` and used as process exit code.
@@ -156,10 +157,20 @@ fn load_config() -> Result<LycheeOptions> {
         }
     } else {
         // If no config file was explicitly provided, we try to load the default
-        // config file from the current directory, but it's not an error if it
-        // doesn't exist.
-        if let Ok(c) = Config::load_from_file(&PathBuf::from(LYCHEE_CONFIG_FILE)) {
-            opts.config.merge(c);
+        // config file from the current directory if the file exits. This will
+        // raise an error if the file is invalid, just like the explicit provided
+        // config file.
+        let default_config = PathBuf::from(LYCHEE_CONFIG_FILE);
+        if default_config.is_file() {
+            match Config::load_from_file(&default_config) {
+                Ok(c) => opts.config.merge(c),
+                Err(e) => {
+                    bail!(
+                        "Cannot load default configuration file `{}`: {e:?}",
+                        default_config.display()
+                    );
+                }
+            }
         }
     }
 
@@ -169,12 +180,16 @@ fn load_config() -> Result<LycheeOptions> {
 
     // TODO: Remove this warning and the parameter with 1.0
     if !&opts.config.exclude_file.is_empty() {
-        warn!("WARNING: `--exclude-file` is deprecated and will soon be removed; use the `{}` file to ignore URL patterns instead. To exclude paths of files and directories, use `--exclude-path`.", LYCHEE_IGNORE_FILE);
+        warn!(
+            "WARNING: `--exclude-file` is deprecated and will soon be removed; use the `{LYCHEE_IGNORE_FILE}` file to ignore URL patterns instead. To exclude paths of files and directories, use `--exclude-path`."
+        );
     }
 
     // TODO: Remove this warning and the parameter with 1.0
-    if opts.config.exclude_mail {
-        warn!("WARNING: `--exclude-mail` is deprecated and will soon be removed; E-Mail is no longer checked by default. Use `--include-mail` to enable E-Mail checking.");
+    if opts.config.base.is_some() {
+        warn!(
+            "WARNING: `--base` is deprecated and will soon be removed; use `--base-url` instead."
+        );
     }
 
     // Load excludes from file
@@ -288,33 +303,51 @@ fn underlying_io_error_kind(error: &Error) -> Option<io::ErrorKind> {
 async fn run(opts: &LycheeOptions) -> Result<i32> {
     let inputs = opts.inputs()?;
 
-    let mut collector = Collector::new(opts.config.root_dir.clone(), opts.config.base.clone())?
-        .skip_missing_inputs(opts.config.skip_missing)
-        .skip_hidden(!opts.config.hidden)
-        .skip_ignored(!opts.config.no_ignore)
-        .include_verbatim(opts.config.include_verbatim)
-        // File a bug if you rely on this envvar! It's going to go away eventually.
-        .use_html5ever(std::env::var("LYCHEE_USE_HTML5EVER").is_ok_and(|x| x == "1"));
+    // TODO: Remove this section after `--base` got removed with 1.0
+    let base = match (opts.config.base.clone(), opts.config.base_url.clone()) {
+        (None, None) => None,
+        (Some(base), None) => Some(base),
+        (None, Some(base_url)) => Some(base_url),
+        (Some(_base), Some(base_url)) => {
+            warn!(
+                "WARNING: Both, `--base` and `--base-url` are set. Using `base-url` and ignoring `--base` (as it's deprecated)."
+            );
+            Some(base_url)
+        }
+    };
 
     if opts.config.dump_inputs {
-        let sources = collector.collect_sources(inputs);
         let exit_code = commands::dump_inputs(
-            sources,
+            inputs,
             opts.config.output.as_ref(),
             &opts.config.exclude_path,
+            &opts.config.extensions,
+            !opts.config.hidden,
+            opts.config.no_ignore,
         )
         .await?;
 
         return Ok(exit_code as i32);
     }
 
+    let mut collector = Collector::new(opts.config.root_dir.clone(), base)?
+        .skip_missing_inputs(opts.config.skip_missing)
+        .skip_hidden(!opts.config.hidden)
+        .skip_ignored(!opts.config.no_ignore)
+        .include_verbatim(opts.config.include_verbatim)
+        .headers(HeaderMap::from_header_pairs(&opts.config.header)?)
+        .excluded_paths(PathExcludes::new(opts.config.exclude_path.clone())?)
+        // File a bug if you rely on this envvar! It's going to go away eventually.
+        .use_html5ever(std::env::var("LYCHEE_USE_HTML5EVER").is_ok_and(|x| x == "1"))
+        .include_wikilinks(opts.config.include_wikilinks);
+
     collector = if let Some(ref basic_auth) = opts.config.basic_auth {
         collector.basic_auth_extractor(BasicAuthExtractor::new(basic_auth)?)
     } else {
         collector
     };
 
-    let requests = collector.collect_links(inputs);
+    let requests = collector.collect_links_from_file_types(inputs, opts.config.extensions.clone());
 
     let cache = load_cache(&opts.config).unwrap_or_default();
     let cache = Arc::new(cache);
@@ -370,7 +403,9 @@ async fn run(opts: &LycheeOptions) -> Result<i32> {
         }
 
         if github_issues && opts.config.github_token.is_none() {
-            warn!("There were issues with GitHub URLs. You could try setting a GitHub token and running lychee again.",);
+            warn!(
+                "There were issues with GitHub URLs. You could try setting a GitHub token and running lychee again.",
+            );
         }
 
         if opts.config.cache {
