@@ -3,10 +3,11 @@
 
 use std::collections::{HashMap, HashSet};
 
-use crate::archive::Suggestion;
 use lychee_lib::{CacheStatus, InputSource, Response, ResponseBody, Status};
 use serde::Serialize;
 
+use crate::formatters::suggestion::Suggestion;
+
 /// Response statistics
 ///
 /// This struct contains various counters for the responses received during a
@@ -65,7 +66,7 @@ impl ResponseStats {
     ///
     /// This function is used to update the counters (success, error, etc.)
     /// based on the given response status.
-    pub(crate) fn increment_status_counters(&mut self, status: &Status) {
+    pub(crate) const fn increment_status_counters(&mut self, status: &Status) {
         match status {
             Status::Ok(_) => self.successful += 1,
             Status::Error(_) => self.errors += 1,
