@@ -106,7 +106,10 @@ impl RetryExt for ErrorKind {
         {
             source.should_retry()
         } else {
-            false
+            matches!(
+                self,
+                Self::RejectedStatusCode(StatusCode::TOO_MANY_REQUESTS)
+            )
         }
     }
 }
