@@ -10,6 +10,7 @@ mod file;
 mod input;
 pub(crate) mod mail;
 mod request;
+pub(crate) mod resolver;
 mod response;
 mod status;
 mod status_code;
@@ -21,7 +22,7 @@ pub use basic_auth::{BasicAuthCredentials, BasicAuthSelector};
 pub use cache::CacheStatus;
 pub use cookies::CookieJar;
 pub use error::ErrorKind;
-pub use file::FileType;
+pub use file::{FileExtensions, FileType};
 pub use input::{Input, InputContent, InputSource};
 pub use request::Request;
 pub use response::{Response, ResponseBody};
